@@ -1,5 +1,5 @@
 /*
- *  This file is part of Poedit (http://poedit.net)
+ *  This file is part of Poedit (https://poedit.net)
  *
  *  Copyright (C) 2014-2016 Vaclav Slavik
  *
@@ -56,9 +56,9 @@ class AutoWrappingText : public wxStaticText
 public:
     AutoWrappingText(wxWindow *parent, const wxString& label);
 
-    void SetLanguage(Language lang) { m_language = lang; }
+    void SetLanguage(Language lang);
+    void SetAlignment(TextDirection dir);
 
-    void SetAlignment(int align);
     void SetAndWrapLabel(const wxString& label);
 
 protected:
