@@ -1,5 +1,5 @@
 /*
- *  This file is part of Poedit (http://poedit.net)
+ *  This file is part of Poedit (https://poedit.net)
  *
  *  Copyright (C) 2010-2016 Vaclav Slavik
  *
@@ -65,6 +65,44 @@
     #define BORDER_OSX(dir, n) Border(dir, 0)
 #endif
 
+
+// ----------------------------------------------------------------------
+// Platform version checks
+// ----------------------------------------------------------------------
+
+#ifdef __WXMSW__
+
+inline bool IsWindows10OrGreater()
+{
+    int osmajor = 0;
+    return wxGetOsVersion(&osmajor, nullptr) == wxOS_WINDOWS_NT && osmajor >= 10;
+}
+
+inline bool IsWindowsXP()
+{
+    int osmajor = 0;
+    wxGetOsVersion(&osmajor, nullptr);
+    return osmajor < 6;
+}
+
+inline bool IsWindows7OrGreater()
+{
+    int verMaj, verMin;
+    wxGetOsVersion(&verMaj, &verMin);
+    return verMaj > 6 || (verMaj == 6 && verMin >= 1);
+}
+
+#endif // __WXMSW__
+
+inline int DoubleBufferingWindowStyle()
+{
+#ifdef __WXMSW__
+    return IsWindowsXP() ? 0 : wxFULL_REPAINT_ON_RESIZE;
+#else
+    return 0;
+#endif
+}
+
 // ----------------------------------------------------------------------
 // Misc helpers
 // ----------------------------------------------------------------------
